@@ -2,7 +2,10 @@ from abc import abstractmethod
 
 from aiohttp.web import Application
 from aiohttp_asgi import ASGIResource
-from aiohttp_asgi.resource import ASGIApplicationType
+from aiohttp_asgi.resource import (
+    ASGIApplicationType, ASGIContext, ASGIMatchInfo, ASGIReceiveType,
+    ASGIScopeType, ASGISendType,
+)
 
 from .aiohttp import AIOHTTPService, AIOHTTPSSLService
 
@@ -40,3 +43,15 @@ class ASGIHTTPSSLService(AIOHTTPSSLService):
 
     async def create_application(self) -> Application:
         return _create_app(await self.create_asgi_app())
+
+
+__all__ = (
+    "ASGIApplicationType",
+    "ASGIContext",
+    "ASGIHTTPService",
+    "ASGIMatchInfo",
+    "ASGIReceiveType",
+    "ASGIResource",
+    "ASGIScopeType",
+    "ASGISendType",
+)
