@@ -14,7 +14,7 @@ CoroutineType = Union[Coroutine[Any, Any, T], Generator[Any, None, T]]
 
 class ServiceMeta(ABCMeta):
     def __new__(
-        cls, name: str, bases: Tuple, namespace: Dict, **kwds: Any
+        cls, name: str, bases: Tuple, namespace: Dict, **kwds: Any,
     ) -> Any:
         instance = super().__new__(
             cls, name, bases, dict(namespace),
@@ -32,7 +32,7 @@ class ServiceMeta(ABCMeta):
             raise TypeError(
                 "Following methods must be coroutine functions",
                 tuple(
-                    "%s.%s" % (name, m)
+                    f"{name}.{m}"
                     for m in instance.__async_required__    # type: ignore
                 ),
             )
@@ -44,7 +44,12 @@ class Service(metaclass=ServiceMeta):
     __async_required__: Tuple[str, ...] = ("start", "stop")
     __required__: Tuple[str, ...] = ()
 
-    __instance_params: Dict[str, Any]
+    _instance_params: Dict[str, Any]
+
+    def __new__(cls, *args: Any, **kwargs: Any) -> "Service":
+        instance = super().__new__(cls)
+        instance._instance_params = {}
+        return instance
 
     def __init__(self, **kwargs: Any):
         lost_kw = self.__required__ - kwargs.keys()
@@ -55,6 +60,17 @@ class Service(metaclass=ServiceMeta):
         self.__context: Optional[Context] = None
         self.__start_event: Optional[asyncio.Event] = None
 
+    def __getattr__(self, key: str) -> Any:
+        try:
+            return self._instance_params[key]
+        except KeyError as e:
+            raise AttributeError() from e
+
+    def __setattr__(self, key: str, value: Any) -> None:
+        super(Service, self).__setattr__(key, value)
+        if key in self._instance_params:
+            self._instance_params[key] = value
+
     @property
     def start_event(self) -> asyncio.Event:
         if self.__start_event is None:
@@ -74,13 +90,13 @@ class Service(metaclass=ServiceMeta):
         self.__start_event = asyncio.Event()
 
     def _set_params(self, **kwargs: Any) -> None:
-        self.__instance_params = kwargs
+        self._instance_params = kwargs
 
         for name, value in kwargs.items():
             setattr(self, name, value)
 
     def __getstate__(self) -> Dict[str, Any]:
-        return self.__instance_params
+        return self._instance_params
 
     def __setstate__(self, state: Dict[str, Any]) -> None:
         self._set_params(**state)
@@ -89,7 +105,7 @@ class Service(metaclass=ServiceMeta):
     async def start(self) -> Any:
         raise NotImplementedError
 
-    async def stop(self, exception: Exception = None) -> Any:
+    async def stop(self, exception: Optional[Exception] = None) -> Any:
         pass
 
 
@@ -104,7 +120,7 @@ class TaskStoreBase(Service, ABC):
         task.add_done_callback(self.tasks.remove)
         return task
 
-    async def stop(self, exc: Exception = None) -> None:
+    async def stop(self, exc: Optional[Exception] = None) -> None:
         await cancel_tasks(self.tasks)
 
 
@@ -118,7 +134,7 @@ class SimpleServer(TaskStoreBase):
     async def start(self) -> None:
         raise NotImplementedError
 
-    async def stop(self, exc: Exception = None) -> None:
+    async def stop(self, exc: Optional[Exception] = None) -> None:
         await super().stop(exc)
 
         if self.server:
